@@ -6,6 +6,9 @@ This module defines base exceptions. It can be imported
 by any other module as it has no dependencies
 """
 
+
+import mimetypes, pathlib
+
 class ErrorMessage(object):
     """Acts as a store for attributes message, section, widget"""
 
@@ -28,6 +31,12 @@ code: %s
        self.widget)
 
 
+class SkiStop(Exception):
+    pass
+
+class SkiRestart(Exception):
+    pass
+
 class SkiError(Exception):
     """Exception used as a parent to other exception classes that carry message information.
     """
@@ -90,13 +99,11 @@ class ServerError(SkiError):
 section is the section name (if it is in a section) of the widget where the message is to be displayed
 widget is the widget name where the message is to be displayed
 status is the html return status
-code is an optional error number you can use to be displayed on the Server Error page, avoid numbers
-9000 to 9999 which are reserved for system use
+code is an optional error number you can use to be displayed on the Server Error page
 """
         SkiError.__init__(self, message, section, widget)
         self.status = status
         # code 0 is default
-        # codes 9000 to 9999 are reserved for system use
         self.code = code
 
 
@@ -151,3 +158,49 @@ Note, skicall.call_data will not be changed.
         # this is set if a FailPage call leads to a responder which raises a GoTo
         self.e_list = []
 
+
+class ServeFile(Exception):
+    """Exception used to return a server file to the client browser"""
+
+    def __init__(self, server_file, status='200 OK', headers=None, enable_cache=None, mimetype=None):
+        """server_file should be a string or pathlib.Path object.
+           If headers is given it will be used, and enable_cache and mimetype will be ignored
+           If headers is not given, then enable_cache and mimetype can optionally be set."""
+        self.server_file = None
+        self.mimetype = None
+        self.status = None
+        self.headers = None
+        self.enable_cache = None
+        if isinstance(server_file, str):
+            self.server_file = pathlib.Path(server_file).expanduser().resolve()
+        elif isinstance(server_file, pathlib.Path):
+            self.server_file = server_file
+        else:
+            return
+        self.status = status
+        if headers is not None:
+            self.headers = headers
+        else:
+            self.headers = [('content-length', str(self.server_file.stat().st_size))]
+            if mimetype is not None:
+                self.mimetype = mimetype
+                self.headers.append(('content-type', mimetype))
+            else:
+                t, e = mimetypes.guess_type(self.server_file.name, strict=False)
+                if t:
+                    self.headers.append(('content-type', t))
+                else:
+                    self.headers.append(('content-type', "application/octet-stream"))
+            if enable_cache is not None:
+                self.enable_cache = enable_cache
+                if enable_cache:
+                    self.headers.append(('cache-control', 'max-age=3600'))
+                else:
+                    self.headers.append(('cache-control','no-cache, no-store, must-revalidate'))
+                    self.headers.append(('Pragma', 'no-cache'))
+                    self.headers.append(('Expires', '0'))
+
+
+
+
+
