@@ -47,10 +47,10 @@ def make_part_for_section(section, json_data):
     return newpart
 
 
-def make_item_for_section(section, json_string):
+def make_item_for_section(proj_ident, section, json_string):
     "Returns object created from json string, the section argument is used to give any items unique names. The object is not inserted, and section remains unchanged"
     item_list = json.loads(json_string, object_pairs_hook=collections.OrderedDict)
-    newitem = _create_item(item_list, section.proj_ident)
+    newitem = _create_item(item_list, proj_ident)
     # ensure widgets and placeholders in newitem have unique names
     if hasattr(newitem, 'set_unique_names'):
         name_list = list(section.widgets.keys()) + list(section.section_places.keys())
@@ -833,8 +833,12 @@ def _create_sectionplaceholder(part_dict, proj_ident):
     if 'mtag' in part_dict:
         mtag = part_dict['mtag']
     else:
-        mtag = "div"    
-    return tag.SectionPlaceHolder(section_name=section_name, placename=placename, multiplier=multiplier, mtag=mtag, brief=brief)
+        mtag = "div"
+    if 'show' in part_dict:
+        show = part_dict['show']
+    else:
+        show = True 
+    return tag.SectionPlaceHolder(section_name=section_name, placename=placename, multiplier=multiplier, mtag=mtag, brief=brief, show=show)
 
 
 def _create_htmlsymbol(part_dict, proj_ident):
