@@ -195,7 +195,8 @@ class ParentPart(object):
     def proj_ident(self):
         if not self.ident_string:
             return ''
-        return self.ident_string.split('_')[0]
+        # ident_string normally starts project_pageident_head-0-... etc
+        return self.ident_string.split('_')[0] ##############################
 
     def insert_id(self, id_string=''):
         """Adds the id_string to the part attributes. If no id_string given
@@ -452,7 +453,7 @@ class Part(ParentPart):
 
     # for formatting; any tag with these names will have its end tag put on
     # a new line
-    tag_list = ["div", "head", "body", "nav", "section", "header", "footer", "form", "table", "tr", "svg"]
+    tag_list = ["div", "head", "body", "nav", "section", "header", "footer", "form", "table", "tr", "svg", "script"]
 
     def __init__(self, tag_name="div", attribs=None, text="", show=True, hide_if_empty=False, brief=''):
         ParentPart.__init__(self, tag_name=tag_name, attribs=attribs, show=show, brief=brief)
@@ -743,7 +744,7 @@ class Part(ParentPart):
                 content += str(part)
         start_tag = "\n<{tag_name}{str_attribs}>".format(tag_name=self.tag_name, str_attribs=self.attributes_string)
         if self.tag_name in self.tag_list:
-            end_tag = "\n</{tag_name}>".format(tag_name=self.tag_name)
+            end_tag = "\n</{tag_name}>\n".format(tag_name=self.tag_name)
         else:
             end_tag = "</{tag_name}>".format(tag_name=self.tag_name)
         return start_tag+content+end_tag
@@ -918,12 +919,14 @@ class Section(Part):
 class SectionPlaceHolder(object):
     "Instance of this is added to a part, and acts as the placeholder for a section"
 
-    def __init__(self, section_name, placename, multiplier=0, mtag="div", brief=''):
+    def __init__(self, section_name, placename, multiplier=0, mtag="div", brief='', show=True):
         self.brief = brief
         self.section_name = section_name
         self.placename = placename
         self.mtag = mtag
         self.ident_string = ''
+        # set show to False if the section at this place is not to be shown
+        self.show = show
         try:
             mult = int(multiplier)
         except Exception:
@@ -936,7 +939,7 @@ class SectionPlaceHolder(object):
     def get_section(self):
         if not self.ident_string:
             return
-        proj_ident = self.ident_string.split('_')[0]
+        proj_ident = self.ident_string.split('_')[0] ########################
         proj = skiboot.getproject(proj_ident)
         if proj is None:
             return
@@ -990,6 +993,7 @@ class SectionPlaceHolder(object):
             part_dict["placename"] = self.placename
         part_dict["multiplier"] = self.multiplier
         part_dict["mtag"] = self.mtag
+        part_dict["show"] = self.show
         return ['SectionPlaceHolder', part_dict]
 
 
