@@ -408,10 +408,10 @@ class SubmitCheckBox1(Widget):
                         'label_style':FieldArg("cssstyle", ''),
                         'action_json':FieldArg("url", ''),
                         'action':FieldArg("url", ''),
-                        'hidden_field1':FieldArg("text", '', valdt=True),
-                        'hidden_field2':FieldArg("text", '', valdt=True),
-                        'hidden_field3':FieldArg("text", '', valdt=True),
-                        'hidden_field4':FieldArg("text", '', valdt=True),
+                        'hidden_field1':FieldArg("text", '', valdt=True, jsonset=True),
+                        'hidden_field2':FieldArg("text", '', valdt=True, jsonset=True),
+                        'hidden_field3':FieldArg("text", '', valdt=True, jsonset=True),
+                        'hidden_field4':FieldArg("text", '', valdt=True, jsonset=True),
                         'button_text':FieldArg("text",'Submit'),
                         'button_class':FieldArg("cssclass", ''),
                         'inputdiv_class':FieldArg("cssclass", ''),
@@ -558,3 +558,121 @@ class SubmitCheckBox1(Widget):
 </div>"""
 
 
+
+
+class CheckBoxTable1(Widget):
+    """A table of three columns, two being text strings, the third checkboxes
+       The first row is three header titles. Typically inserted into a form
+       does not display errors"""
+
+    display_errors = False
+
+
+    arg_descriptions = {'header_class':FieldArg("cssclass",""),
+                        'title1':FieldArg('text', ''),
+                        'title2':FieldArg('text', ''),
+                        'title3':FieldArg('text', ''),
+                        'row_classes':FieldArgList('text', jsonset=True),
+                        'col1':FieldArgList('text', jsonset=True),
+                        'col2':FieldArgList('text', jsonset=True),
+                        'checkbox_dict':FieldArgDict('text'),                                     # dictionary of keyname:value
+                        'checked':FieldArgList("text", valdt=True, jsonset=True, senddict=True)  # the field submitted as a dictionary
+                        }                                                                         # each key will have 'keyname'
+                                                                                                  # and value will be the values ticked
+
+
+    def __init__(self, name=None, brief='', **field_args):
+        """
+        header_class: class of the header row, if empty string, then no class will be applied
+        title1: The header title over the first text column
+        title2: The header title over the second text column
+        title3: The header title over the second text column
+        row_classes: A list of CSS classes to apply to each row (not including the header)
+        col1: A list of text strings to place in the first column
+        col2: A list of text strings to place in the second column
+        checkbox_dict: A dictionary of keyname:value, should be Ordered Dict unless python >= 3.6
+        checked: a list of keynames which will be checked,  the fields submitted will have name 'widgetname:checked-keyname'
+                       and the user will receive a widgfield ('widgetname','checked') containing a dictionary of keyname:values ticked
+         """
+        Widget.__init__(self, name=name, tag_name="table", brief=brief, **field_args)
+
+
+    def _build(self, page, ident_list, environ, call_data, lang):
+        "Build the table"
+        checkbox_dict = self.get_field_value("checkbox_dict")
+        rowc = self.get_field_value("row_classes")
+        col1 = self.get_field_value("col1")
+        col2 = self.get_field_value("col2")
+        checked = self.get_field_value('checked')
+        if not checked:
+            checked = []
+        input_name = self.get_formname("checked") + '-'
+
+        header = 0
+        if self.get_field_value('title1') or self.get_field_value('title2') or self.get_field_value('title3'):
+            header = 1
+            if self.get_field_value('header_class'):
+                self[0] = tag.Part(tag_name='tr', attribs={"class":self.get_field_value('header_class')})
+            else:
+                self[0] = tag.Part(tag_name='tr')
+            self[0][0] = tag.Part(tag_name='th', text = self.get_field_value('title1'))
+            self[0][1] = tag.Part(tag_name='th', text = self.get_field_value('title2'))
+            self[0][2] = tag.Part(tag_name='th', text = self.get_field_value('title3'))
+
+        # create rows
+        rows = max( len(col1), len(col2), len(checkbox_dict) )
+        if not rowc:
+            rowc = ['']*rows
+        if rows > len(rowc):
+            rowc.extend(['']*(rows - len(rowc)))
+        if rows > len(col1):
+            col1.extend(['']*(rows - len(col1)))
+        if rows > len(col2):
+            col2.extend(['']*(rows - len(col2)))
+
+        keylist = list(checkbox_dict.keys())
+        if rows > len(keylist):
+            keylist.extend([None]*(rows - len(keylist)))
+
+        # keylist is a list of the dictionary keys, extended by None keys, if the dictionary is smaller than the number of rows of the table
+        
+        for index in range(rows):
+            rownumber = index+header
+            if rowc[index]:
+                self[rownumber] = tag.Part(tag_name='tr', attribs={"class":rowc[index]})
+            else:
+                self[rownumber] = tag.Part(tag_name='tr')
+            self[rownumber][0] = tag.Part(tag_name='td', text = col1[index])
+            self[rownumber][1] = tag.Part(tag_name='td', text = col2[index])
+            self[rownumber][2] = tag.Part(tag_name='td')
+            key = keylist[index]
+            if key:  # this is the dictionary key
+                keyed_name = input_name + key
+                self[rownumber][2][0] = tag.ClosedPart(tag_name="input", attribs={"name":keyed_name, "type":"checkbox"})
+                if key in checked:
+                    self[rownumber][2][0].update_attribs({"value":checkbox_dict[key], "checked":"checked"})
+                else:
+                    self[rownumber][2][0].update_attribs({"value":checkbox_dict[key]})
+
+
+    @classmethod
+    def description(cls):
+        """Returns a text string to illustrate the widget"""
+        return """
+<table>  <!-- with widget id and class widget_class -->
+  <tr> <!-- with header class -->
+    <th> <!-- title1 --> </th>
+    <th> <!-- title2 --> </th>
+    <th> <!-- title3 --> </th>
+  </tr>
+  <tr> <!-- with class from row_classes -->
+    <td> <!-- col1 text string --> </td>
+    <td> <!-- col2 text string --> </td>
+    <td><input type="checkbox" />  <!-- with names and value derived from 'checkbox_dict' -->
+    </td>
+  </tr>
+  <!-- rows repeated -->
+</table>"""
+
+
+
