@@ -260,6 +260,38 @@ class TagText(Widget):
 </div>"""
 
 
+class TagUnEscaped(Widget):
+    """A tag, which can be specified, containing unescaped content"""
+
+     # This class does not display any error messages
+    display_errors = False
+
+    arg_descriptions = {'tag':FieldArg("text", 'div'),
+                        'content':FieldArg("text", "", jsonset=True)}
+
+    def __init__(self, name=None, brief='', **field_args):
+        """
+        content: The content appearing in the tag
+        """
+        # pass fields to Widget
+        Widget.__init__(self, name=name, tag_name="div", brief=brief, **field_args)
+        self[0] = ''
+        self.htmlescaped = False
+        self.linebreaks=False
+
+    def _build(self, page, ident_list, environ, call_data, lang):
+        self.tag_name = self.get_field_value('tag')
+        self[0] = self.get_field_value("content")
+
+    @classmethod
+    def description(cls):
+        """Returns a text string to illustrate the widget"""
+        return """
+<div>  <!-- with widget id and class widget_class and with div tag, or any other specified -->
+    <!-- set with content -->
+</div>"""
+
+
 class ParaText(Widget):
     """A p tag, containing text"""
 
@@ -557,7 +589,7 @@ class JSONDivLink(Widget):
   <a href="#" role="button">  <!-- with class button_class -->
     <!-- set with button_show_text or button_hide_text -->
   </a>
-  <div>  <!-- with class div_class, and either hidden or not, depending on hide -->
+  <div>  <!-- with class div_class, style div_style, and either hidden or not, depending on hide -->
     <!-- div_content shown as either text or html -->
   </div>
 </div>"""
