@@ -385,10 +385,10 @@ class ButtonTextBlockTable1(Widget):
                         'odd_class':FieldArg("cssclass", ""),
                         'col1_button_title':FieldArg('text', ''),
                         'col2_text_title':FieldArg('text', ''),
-                        'hidden_field1':FieldArg("text", valdt=True),
-                        'hidden_field2':FieldArg("text", valdt=True),
-                        'hidden_field3':FieldArg("text", valdt=True),
-                        'hidden_field4':FieldArg("text", valdt=True),
+                        'hidden_field1':FieldArg("text", valdt=True, jsonset=True),
+                        'hidden_field2':FieldArg("text", valdt=True, jsonset=True),
+                        'hidden_field3':FieldArg("text", valdt=True, jsonset=True),
+                        'hidden_field4':FieldArg("text", valdt=True, jsonset=True),
                         'buttons':FieldArgTable(['text', 'textblock_ref'], valdt=True),
                         'button_class':FieldArg("cssclass", ''),
                         'error_class':FieldArg("cssclass", ''),
