@@ -7,6 +7,8 @@ import collections
 
 from ... import ValidateError, FailPage, ServerError
 
+from ....ski.project_class_definition import SectionData
+
 from ... import skilift
 from ....skilift import editpage
 
@@ -17,7 +19,7 @@ def retrieve_edit_csspage(skicall):
     "Retrieves widget data for the edit css page"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     # clears any session data, keeping page_number, pchange and any status message
     utils.clear_call_data(call_data, keep=["page_number", "pchange", "status"])
@@ -41,14 +43,23 @@ def retrieve_edit_csspage(skicall):
     except ServerError as e:
         raise FailPage(message = e.message)
 
+    # fill in sections
+
+    sd_adminhead = SectionData("adminhead")
+    sd_page_edit = SectionData("page_edit")
+
     # fills in the data for editing page name, brief, parent, etc., 
-    page_data[("adminhead","page_head","large_text")] = pageinfo.name
-    page_data[('page_edit','p_ident','page_ident')] = (project,str_pagenumber)
-    page_data[('page_edit','p_name','page_ident')] = (project,str_pagenumber)
-    page_data[('page_edit','p_description','page_ident')] = (project,str_pagenumber)
-    page_data[('page_edit','p_rename','input_text')] = pageinfo.name
-    page_data[('page_edit','p_parent','input_text')] = "%s,%s" % (project, pageinfo.parentfolder_number)
-    page_data[('page_edit','p_brief','input_text')] = pageinfo.brief
+    sd_adminhead["page_head","large_text"] = pageinfo.name
+    sd_page_edit['p_ident','page_ident'] = (project,str_pagenumber)
+    sd_page_edit['p_name','page_ident'] = (project,str_pagenumber)
+    sd_page_edit['p_description','page_ident'] = (project,str_pagenumber)
+    sd_page_edit['p_rename','input_text'] = pageinfo.name
+    sd_page_edit['p_parent','input_text'] = "%s,%s" % (project, pageinfo.parentfolder_number)
+    sd_page_edit['p_brief','input_text'] = pageinfo.brief
+
+    pd.update(sd_adminhead)
+    pd.update(sd_page_edit)
+
     # create the contents for the selectortable
     contents = []
 
@@ -66,18 +77,18 @@ def retrieve_edit_csspage(skicall):
                 # last item has no down button
                 down = False 
             contents.append([selector, selector, selector, selector, selector, True, up, down, True])
-        page_data["selectortable:contents"] = contents
+        pd["selectortable","contents"] = contents
     else:
-        page_data["selectortable:show"] = False
+        pd["selectortable","show"] = False
 
-    page_data['enable_cache:radio_checked'] = pageinfo.enable_cache
+    pd['enable_cache','radio_checked'] = pageinfo.enable_cache
 
 
 def retrieve_edit_selector(skicall):
     "Retrieves widget data for the edit selector page"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     project = call_data['editedprojname']
     if 'page_number' in call_data:
@@ -106,20 +117,22 @@ def retrieve_edit_selector(skicall):
     else:
         status_text = 'Edit selector : %s' % (edit_selector,)
 
-    page_data.update({("adminhead","page_head","large_text"):"Edit CSS page : %s" % (pageinfo.name,),
-                      ("adminhead","page_head","small_text"):status_text,
-                      ('selectorname','para_text'):"Selector : %s" % (edit_selector,),
-                      ('p_ident','page_ident'):(project,str_pagenumber),
-                      ('properties','hidden_field1'):edit_selector,
-                      ('properties','input_text'):property_string })
+    sd_adminhead = SectionData("adminhead")
+    sd_adminhead["page_head","large_text"] = "Edit CSS page : %s" % (pageinfo.name,)
+    sd_adminhead["page_head","small_text"] = status_text
+    pd.update(sd_adminhead)
 
+    pd['selectorname','para_text'] = "Selector : %s" % (edit_selector,)
+    pd['p_ident','page_ident'] = (project,str_pagenumber)
+    pd['properties','hidden_field1'] = edit_selector
+    pd['properties','input_text'] = property_string
 
 
 def retrieve_print_csspage(skicall):
     "Retrieves widget data for the print css page"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     project = call_data['editedprojname']
     if 'page_number' in call_data:
@@ -135,15 +148,14 @@ def retrieve_print_csspage(skicall):
         page_string = editpage.page_string(project, pagenumber)
     except ServerError as e:
         raise FailPage(message = e.message)
-    page_data['page_details:para_text'] = "/**************************\n\nIdent:%s,%s\nPath:%s\n%s" % (project, pagenumber, pageinfo.path, pageinfo.brief)
-    page_data['page_contents:para_text'] = page_string
+    pd['page_details','para_text'] = "/**************************\n\nIdent:%s,%s\nPath:%s\n%s" % (project, pagenumber, pageinfo.path, pageinfo.brief)
+    pd['page_contents','para_text'] = page_string
 
 
 def submit_new_selector(skicall):
     "Sets new selector"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     if 'page_number' in call_data:
@@ -174,7 +186,6 @@ def submit_delete_selector(skicall):
     "Deletes selector"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     if 'page_number' in call_data:
@@ -205,7 +216,6 @@ def submit_selector_properties(skicall):
     "Sets the selector properties"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     if 'page_number' in call_data:
@@ -249,7 +259,6 @@ def move_selector_up(skicall):
     "Moves selector upwards"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     if 'page_number' in call_data:
@@ -285,7 +294,6 @@ def move_selector_down(skicall):
     "Moves selector downwardswards"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     if 'page_number' in call_data:
@@ -321,7 +329,6 @@ def submit_cache(skicall):
     "Sets cache true or false"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     pagenumber = call_data['page_number']
