@@ -9,6 +9,8 @@ from ... import ValidateError, FailPage, ServerError, GoTo
 from ... import skilift
 from ....skilift import fromjson, part_contents, editpage
 
+from ....ski.project_class_definition import SectionData
+
 from .. import utils
 
 
@@ -16,7 +18,7 @@ def retrieve_page_edit(skicall):
     "Retrieves data for the edit page"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     # clears any session data, keeping page_number, pchange and any status message
     utils.clear_call_data(call_data, keep=["page_number", "pchange", "status"])
@@ -36,14 +38,20 @@ def retrieve_page_edit(skicall):
 
         call_data['pchange'] = pageinfo.change
 
+        sd_adminhead = SectionData("adminhead")
+        sd_page_edit = SectionData("page_edit")
+
         # fills in the data for editing page name, brief, parent, etc., 
-        page_data[("adminhead","page_head","large_text")] = pageinfo.name
-        page_data[('page_edit','p_ident','page_ident')] = (project,str_pagenumber)
-        page_data[('page_edit','p_name','page_ident')] = (project,str_pagenumber)
-        page_data[('page_edit','p_description','page_ident')] = (project,str_pagenumber)
-        page_data[('page_edit','p_rename','input_text')] = pageinfo.name
-        page_data[('page_edit','p_parent','input_text')] = "%s,%s" % (project, pageinfo.parentfolder_number)
-        page_data[('page_edit','p_brief','input_text')] = pageinfo.brief
+        sd_adminhead["page_head","large_text"] = pageinfo.name
+        sd_page_edit['p_ident','page_ident'] = (project,str_pagenumber)
+        sd_page_edit['p_name','page_ident'] = (project,str_pagenumber)
+        sd_page_edit['p_description','page_ident'] = (project,str_pagenumber)
+        sd_page_edit['p_rename','input_text'] = pageinfo.name
+        sd_page_edit['p_parent','input_text'] = "%s,%s" % (project, pageinfo.parentfolder_number)
+        sd_page_edit['p_brief','input_text'] = pageinfo.brief
+
+        pd.update(sd_adminhead)
+        pd.update(sd_page_edit)
 
         pageOD = fromjson.page_to_OD(project, pagenumber)
     except ServerError as e:
@@ -55,32 +63,37 @@ def retrieve_page_edit(skicall):
         raise FailPage(message="This page not recognised as a Template page.")
 
     # page language
-    page_data[("setlang","input_text")] = pagedict["lang"]
+    pd["setlang","input_text"] = pagedict["lang"]
 
     # default error widget
     dew = pagedict["default_error_widget"]
     if dew[0]:
-        page_data[("default_e_widg","input_text")] = dew[0] + ',' + dew[1]
+        pd["default_e_widg","input_text"] = dew[0] + ',' + dew[1] ############
+        pd["d_e_section","input_text"] = dew[0]
+        pd["d_e_widget","input_text"] = dew[1]
+
     elif dew[1]:
-        page_data[("default_e_widg","input_text")] = dew[1]
+        pd["default_e_widg","input_text"] = dew[1]                #############
+        pd["d_e_widget","input_text"] = dew[1]
 
     # sets last_scroll flag
-    page_data[("lastscroll","checked")] = pagedict["last_scroll"]
+    pd["lastscroll","checked"] = pagedict["last_scroll"]
 
     # fills in the backcolor checkbox and value
     if pagedict["show_backcol"]:
-        page_data[("enablebackcolor","checked")] = True
-        page_data[('setbackcolor', 'hide')] = False
+        pd["enablebackcolor","checked"] = True
+        pd['setbackcolor', 'hide'] = False
     else:
-        page_data[("enablebackcolor","checked")] = False
-        page_data[('setbackcolor', 'hide')] = True
-    page_data[('setbackcolor', 'input_text')] = pagedict["backcol"]
+        pd["enablebackcolor","checked"] = False
+        pd['setbackcolor', 'hide'] = True
+
+    pd['setbackcolor', 'input_text'] = pagedict["backcol"]
 
     # Sets CatchToHTML
     if pagedict["catch_to_html"] is None:
-        page_data["set_catch_to_html", "input_text"] = ''
+        pd["set_catch_to_html", "input_text"] = ''
     else:
-        page_data["set_catch_to_html", "input_text"] = str(pagedict["catch_to_html"])
+        pd["set_catch_to_html", "input_text"] = str(pagedict["catch_to_html"])
 
     # fills in the JSON refresh checkbox
     if pagedict["interval"] and pagedict["interval_target"]:
@@ -88,24 +101,24 @@ def retrieve_page_edit(skicall):
             interval_target = ''
         else:
             interval_target = str(pagedict["interval_target"])
-        page_data[("refreshcheck","checked")] = True
-        page_data[('interval', 'disabled')] = False
-        page_data[('interval_target', 'disabled')] = False
-        page_data[('interval', 'input_text')] = str(pagedict["interval"])
-        page_data[('interval_target', 'input_text')] = interval_target
+        pd["refreshcheck","checked"] = True
+        pd['interval', 'disabled'] = False
+        pd['interval_target', 'disabled'] = False
+        pd['interval', 'input_text'] = str(pagedict["interval"])
+        pd['interval_target', 'input_text'] = interval_target
     else:
-        page_data[("refreshcheck","checked")] = False
-        page_data[('interval', 'disabled')] = True
-        page_data[('interval_target', 'disabled')] = True
-        page_data[('interval', 'input_text')] = '0'
-        page_data[('interval_target', 'input_text')] = ''
+        pd["refreshcheck","checked"] = False
+        pd['interval', 'disabled'] = True
+        pd['interval_target', 'disabled'] = True
+        pd['interval', 'input_text'] = '0'
+        pd['interval_target', 'input_text'] = ''
 
 
 def retrieve_page_head(skicall):
     "Gets data for the page head"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     project = call_data['editedprojname']
 
@@ -125,8 +138,11 @@ def retrieve_page_head(skicall):
     if pageinfo.item_type != 'TemplatePage':
         raise FailPage(message = "Invalid page")
 
-    page_data[("adminhead","page_head","large_text")] = pageinfo.name + ' head'
-    page_data["pageid", "para_text"] = "Page Ident: " + str(pagenumber)
+    sd_adminhead = SectionData("adminhead")
+    sd_adminhead["page_head","large_text"] = pageinfo.name + ' head'
+    pd.update(sd_adminhead)
+
+    pd["pageid", "para_text"] = "Page Ident: " + str(pagenumber)
 
     # fill in the table
     call_data['location_string'] = 'head'
@@ -137,7 +153,7 @@ def retrieve_page_dom(skicall):
     "this call fills in the page dom table"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     project = call_data['editedprojname']
 
@@ -179,27 +195,29 @@ def retrieve_page_dom(skicall):
     #                       If True a link to link_ident/json_ident will be set with button_class applied to it
     #               3 - The get field value of the button link, empty string if no get field
 
-   
-    page_data['editdom', 'domtable', 'contents']  = domcontents
-    page_data['editdom', 'domtable', 'dragrows']  = dragrows
-    page_data['editdom', 'domtable', 'droprows']  = droprows
+    sd_editdom = SectionData("editdom")
+    sd_editdom['domtable', 'contents']  = domcontents
+    sd_editdom['domtable', 'dragrows']  = dragrows
+    sd_editdom['domtable', 'droprows']  = droprows
 
     # for each column: html link, JSON link, storage key
-    page_data['editdom', 'domtable', 'cols']  =  [    ['','',''],                                          # tag name, no link
-                                                      ['','',''],                                          # brief, no link
-                                                      ['no_javascript','move_up_in_page_dom',''],          # up arrow
-                                                      ['no_javascript','move_up_right_in_page_dom',''],    # up right
-                                                      ['no_javascript','move_down_in_page_dom',''],        # down
-                                                      ['no_javascript','move_down_right_in_page_dom',''],  # down right
-                                                      ['edit_page_dom','',''],                             # edit, html only
-                                                      ['no_javascript','insert_in_page',''],               # insert/append
-                                                      ['no_javascript',3680,''],                           # copy
-                                                      ['no_javascript',3690,'ski_part'],                   # paste
-                                                      ['no_javascript','cut_page_dom',''],                 # cut
-                                                      ['no_javascript','delete_page_dom','']               # delete
-                                                   ]
+    sd_editdom['domtable', 'cols']  =  [  ['','',''],                                          # tag name, no link
+                                          ['','',''],                                          # brief, no link
+                                          ['no_javascript','move_up_in_page_dom',''],          # up arrow
+                                          ['no_javascript','move_up_right_in_page_dom',''],    # up right
+                                          ['no_javascript','move_down_in_page_dom',''],        # down
+                                          ['no_javascript','move_down_right_in_page_dom',''],  # down right
+                                          ['edit_page_dom','',''],                             # edit, html only
+                                          ['no_javascript','insert_in_page',''],               # insert/append
+                                          ['no_javascript',3680,''],                           # copy
+                                          ['no_javascript',3690,'ski_part'],                   # paste
+                                          ['no_javascript','cut_page_dom',''],                 # cut
+                                          ['no_javascript','delete_page_dom','']               # delete
+                                       ]
 
-    page_data['editdom', 'domtable', 'dropident']  = 'move_in_page_dom'
+    sd_editdom['domtable', 'dropident']  = 'move_in_page_dom'
+
+    pd.update(sd_editdom)
 
     # remove any unwanted fields from session call_data
     if 'location' in call_data:
@@ -222,7 +240,7 @@ def retrieve_page_body(skicall):
     "Gets data for the page body"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     project = call_data['editedprojname']
 
@@ -242,8 +260,11 @@ def retrieve_page_body(skicall):
     if pageinfo.item_type != 'TemplatePage':
         raise FailPage(message = "Invalid page")
 
-    page_data[("adminhead","page_head","large_text")] = pageinfo.name + ' body'
-    page_data["pageid", "para_text"] = "Page Ident: " + str(pagenumber)
+    sd_adminhead = SectionData("adminhead")
+    sd_adminhead["page_head","large_text"] = pageinfo.name + ' body'
+    pd.update(sd_adminhead)
+
+    pd["pageid", "para_text"] = "Page Ident: " + str(pagenumber)
 
     # fill in the table
     call_data['location_string'] = 'body'
@@ -252,9 +273,9 @@ def retrieve_page_body(skicall):
 
 
 def copy_page(skicall):
-    "Gets page part and return it in page_data['localStorage'] with key ski_part for browser session storage"
+    "Gets page part and set PageData().localStorage with key ski_part for browser session storage"
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
@@ -292,14 +313,14 @@ def copy_page(skicall):
         jsonstring = json.dumps(['Part',itemdict], indent=0, separators=(',', ':'))
     else:
         jsonstring = json.dumps([itempart,itemdict], indent=0, separators=(',', ':'))
-    page_data['localStorage'] = {'ski_part':jsonstring}
+    pd.localStorage = {'ski_part':jsonstring}
     call_data['status'] = 'Item copied, and can now be pasted.'
 
 
 def paste_page(skicall):
     "Gets submitted json string and inserts it"
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
@@ -337,9 +358,12 @@ def paste_page(skicall):
     call_data['pchange'] = editpage.create_item_in_page(editedprojname, pagenumber, call_data['pchange'], location, json_string)
 
     domcontents, dragrows, droprows = _page_domcontents(editedprojname, pagenumber, location_string)
-    page_data['editdom', 'domtable', 'dragrows']  = dragrows
-    page_data['editdom', 'domtable', 'droprows']  = droprows
-    page_data['editdom', 'domtable', 'contents']  = domcontents
+
+    sd_editdom = SectionData("editdom")
+    sd_editdom['domtable', 'dragrows']  = dragrows
+    sd_editdom['domtable', 'droprows']  = droprows
+    sd_editdom['domtable', 'contents']  = domcontents
+    pd.update(sd_editdom)
 
 
 
@@ -347,7 +371,7 @@ def retrieve_svgpage_edit(skicall):
     "Retrieves widget data for the svg edit page"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     # clears any session data, keeping page_number, pchange and any status message
     utils.clear_call_data(call_data, keep=["page_number", "pchange", "status"])
@@ -367,15 +391,22 @@ def retrieve_svgpage_edit(skicall):
 
         call_data['pchange'] = pageinfo.change
 
-        # fills in the data for editing page name, brief, parent, etc., 
-        page_data[("adminhead","page_head","large_text")] = pageinfo.name
-        page_data[('page_edit','p_ident','page_ident')] = (project,str_pagenumber)
-        page_data[('page_edit','p_name','page_ident')] = (project,str_pagenumber)
-        page_data[('page_edit','p_description','page_ident')] = (project,str_pagenumber)
-        page_data[('page_edit','p_rename','input_text')] = pageinfo.name
-        page_data[('page_edit','p_parent','input_text')] = "%s,%s" % (project, pageinfo.parentfolder_number)
-        page_data[('page_edit','p_brief','input_text')] = pageinfo.brief
-        page_data['enable_cache:radio_checked'] = pageinfo.enable_cache
+        # fills in the data for editing page name, brief, parent, etc.,
+
+        sd_adminhead = SectionData("adminhead")
+        sd_adminhead["page_head","large_text"] = pageinfo.name
+        pd.update(sd_adminhead)
+
+        sd_page_edit = SectionData("page_edit")
+        sd_page_edit['p_ident','page_ident'] = (project,str_pagenumber)
+        sd_page_edit['p_name','page_ident'] = (project,str_pagenumber)
+        sd_page_edit['p_description','page_ident'] = (project,str_pagenumber)
+        sd_page_edit['p_rename','input_text'] = pageinfo.name
+        sd_page_edit['p_parent','input_text'] = "%s,%s" % (project, pageinfo.parentfolder_number)
+        sd_page_edit['p_brief','input_text'] = pageinfo.brief
+        pd.update(sd_page_edit)
+
+        pd['enable_cache','radio_checked'] = pageinfo.enable_cache
 
     except ServerError as e:
         raise FailPage(message=e.message)
@@ -385,7 +416,7 @@ def retrieve_page_svg(skicall):
     "Gets data for the page svg part"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     project = call_data['editedprojname']
 
@@ -401,8 +432,12 @@ def retrieve_page_svg(skicall):
         raise FailPage(message = e.message)
     if pageinfo.item_type != 'SVG':
         raise FailPage(message = "Invalid page")
-    page_data[("adminhead","page_head","large_text")] = pageinfo.name + ' svg'
-    page_data["pageid", "para_text"] = "Page Ident: " + str(pagenumber)
+
+    sd_adminhead = SectionData("adminhead")
+    sd_adminhead["page_head","large_text"] = pageinfo.name + ' svg'
+    pd.update(sd_adminhead)
+
+    pd["pageid", "para_text"] = "Page Ident: " + str(pagenumber)
     # fill in the table
     call_data['location_string'] = 'svg'
     retrieve_page_dom(skicall)
@@ -412,7 +447,6 @@ def set_html_lang(skicall):
     "Sets language in the page html tag"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     pagenumber = call_data['page_number']
@@ -435,7 +469,6 @@ def enable_backcolour(skicall):
     """Enables background colour in HTML tag"""
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     pagenumber = call_data['page_number']
@@ -461,7 +494,6 @@ def set_backcolour(skicall):
     """Sets the background colour in the HTML tag"""
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     pagenumber = call_data['page_number']
@@ -490,7 +522,6 @@ def set_last_scroll(skicall):
     "Sets page last_scroll flag"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     pagenumber = call_data['page_number']
@@ -514,7 +545,6 @@ def set_catch_to_html(skicall):
     """Sets the CatchToHTML target"""
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     pagenumber = call_data['page_number']
@@ -538,7 +568,6 @@ def submit_refresh(skicall):
     "Sets JSON refresh facility"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     pagenumber = call_data['page_number']
@@ -579,29 +608,35 @@ def submit_refresh(skicall):
     call_data['status'] = text
 
 
-def submit_default_error_widget(skicall):
+
+def set_default_error_widget(skicall):
     "Sets page default_error_widget"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     pagenumber = call_data['page_number']
     pchange = call_data['pchange']
-    if ('e_widg' not in call_data) or (not call_data['e_widg']):
+
+    if (("d_e_widget","input_text") not in call_data) or (not call_data["d_e_widget","input_text"]):
         raise FailPage(message="Error setting default error widget")
+
+    if (("d_e_section","input_text") in call_data) and call_data["d_e_section","input_text"]:
+        default_widget = call_data["d_e_section","input_text"] + ',' + call_data["d_e_widget","input_text"]
+    else:
+        default_widget = call_data["d_e_widget","input_text"]
     try:
-        call_data['pchange'] = editpage.page_default_error_widget(project, pagenumber, pchange, call_data['e_widg'])
+        call_data['pchange'] = editpage.page_default_error_widget(project, pagenumber, pchange, default_widget)
     except ServerError as e:
         raise FailPage(message=e.message)
     call_data['status'] = "default error widget set"
 
 
+
 def submit_cache(skicall):
     "Sets cache true or false"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     pagenumber = call_data['page_number']
@@ -629,7 +664,7 @@ def retrieve_edit_jsonpage(skicall):
     "Retrieves widget data for the edit json page"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     # clears any session data, keeping page_number, pchange and any status message
     utils.clear_call_data(call_data, keep=["page_number", "pchange", "status"])
@@ -655,14 +690,20 @@ def retrieve_edit_jsonpage(skicall):
     except ServerError as e:
         raise FailPage(message = e.message)
 
-   # fills in the data for editing page name, brief, parent, etc., 
-    page_data[("adminhead","page_head","large_text")] = pageinfo.name
-    page_data[('page_edit','p_ident','page_ident')] = (project,str_pagenumber)
-    page_data[('page_edit','p_name','page_ident')] = (project,str_pagenumber)
-    page_data[('page_edit','p_description','page_ident')] = (project,str_pagenumber)
-    page_data[('page_edit','p_rename','input_text')] = pageinfo.name
-    page_data[('page_edit','p_parent','input_text')] = "%s,%s" % (project, pageinfo.parentfolder_number)
-    page_data[('page_edit','p_brief','input_text')] = pageinfo.brief
+    # fills in the data for editing page name, brief, parent, etc.,
+
+    sd_adminhead = SectionData("adminhead")
+    sd_adminhead["page_head","large_text"] = pageinfo.name
+    pd.update(sd_adminhead)
+
+    sd_page_edit = SectionData("page_edit")
+    sd_page_edit['p_ident','page_ident'] = (project,str_pagenumber)
+    sd_page_edit['p_name','page_ident'] = (project,str_pagenumber)
+    sd_page_edit['p_description','page_ident'] = (project,str_pagenumber)
+    sd_page_edit['p_rename','input_text'] = pageinfo.name
+    sd_page_edit['p_parent','input_text'] = "%s,%s" % (project, pageinfo.parentfolder_number)
+    sd_page_edit['p_brief','input_text'] = pageinfo.brief
+    pd.update(sd_page_edit)
 
     json_content = editpage.json_contents(project, pagenumber)
 
@@ -679,21 +720,20 @@ def retrieve_edit_jsonpage(skicall):
             else:
                 contents.append([wfcomma,value,wfstr])
         if contents:
-            page_data['field_values_list','show'] = True
-            page_data['field_values_list','contents'] = contents
+            pd['field_values_list','show'] = True
+            pd['field_values_list','contents'] = contents
         else:
-            page_data['field_values_list','show'] = False
+            pd['field_values_list','show'] = False
     else:
-        page_data['field_values_list','show'] = False
+        pd['field_values_list','show'] = False
 
-    page_data['enable_cache:radio_checked'] = pageinfo.enable_cache
+    pd['enable_cache','radio_checked'] = pageinfo.enable_cache
 
 
 def set_json_cache(skicall):
     "Sets cache true or false"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     pagenumber = call_data['page_number']
@@ -718,7 +758,6 @@ def remove_json_widgfield(skicall):
     "Removes widgfield from JSON page"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     pagenumber = call_data['page_number']
@@ -733,19 +772,28 @@ def remove_json_widgfield(skicall):
     call_data['status'] = "Widgfield removed"
 
 
-
 def add_json_widgfield(skicall):
     "Adds a widgfield to JSON page"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     pagenumber = call_data['page_number']
     pchange = call_data['pchange']
-    if not ('jsonwidgfield', 'input_text') in call_data:
-        raise FailPage(message="No widgfield given")
-    str_widgfield = call_data[ 'jsonwidgfield', 'input_text']
+
+    str_widgfield = ""
+
+    if (('jsonsection', 'input_text') in call_data) and call_data['jsonsection', 'input_text']:
+        str_widgfield = str_widgfield + ',' + call_data['jsonsection', 'input_text']
+    jsonwidget = call_data.get(('jsonwidget', 'input_text'))
+    if not jsonwidget:
+        raise FailPage(message="No widget given")
+    str_widgfield = str_widgfield + ',' + jsonwidget
+    jsonfield = call_data.get(('jsonfield', 'input_text'))
+    if not jsonfield:
+        raise FailPage(message="No widget field given")
+    str_widgfield = str_widgfield + ',' + jsonfield
+
     if call_data['jsontrue', 'button_text'] == 'True':
         value = True
     elif call_data['jsonfalse', 'button_text'] == 'False':
@@ -758,14 +806,14 @@ def add_json_widgfield(skicall):
         call_data['pchange'] = editpage.add_json_widgfield(project, pagenumber, pchange, str_widgfield, value)
     except ServerError as e:
         raise FailPage(message=e.message)
-    call_data['status'] = "Widgfield added"
+    call_data['status'] = "Widget field value added"
 
 
 def downloadpage(skicall):
     "Gets template or SVG page, and returns a json dictionary, this will be sent as an octet file to be downloaded"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     if 'page_number' in call_data:
         pagenumber = call_data['page_number']
@@ -789,7 +837,8 @@ def downloadpage(skicall):
         binline = line.encode('utf-8')
         n += len(binline)
         line_list.append(binline)
-    page_data['headers'] = [('content-type', 'application/octet-stream'), ('content-length', str(n))]
+    pd.mimetype = 'application/octet-stream'
+    pd.content_length = str(n)
     return line_list
 
 
@@ -797,7 +846,7 @@ def move_up_in_page_dom(skicall):
     "Called by domtable to move an item in a page up"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
@@ -866,9 +915,12 @@ def move_up_in_page_dom(skicall):
 
     # and re-draw the table
     domcontents, dragrows, droprows = _page_domcontents(editedprojname, pagenumber, location_string)
-    page_data['editdom', 'domtable', 'dragrows']  = dragrows
-    page_data['editdom', 'domtable', 'droprows']  = droprows
-    page_data['editdom', 'domtable', 'contents']  = domcontents
+
+    sd_editdom = SectionData("editdom")
+    sd_editdom['domtable', 'dragrows']  = dragrows
+    sd_editdom['domtable', 'droprows']  = droprows
+    sd_editdom['domtable', 'contents']  = domcontents
+    pd.update(sd_editdom)
 
 
 
@@ -876,7 +928,7 @@ def move_up_right_in_page_dom(skicall):
     "Called by domtable to move an item in a page up and to the right"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
@@ -951,9 +1003,13 @@ def move_up_right_in_page_dom(skicall):
 
     # and re-draw the table
     domcontents, dragrows, droprows = _page_domcontents(editedprojname, pagenumber, location_string)
-    page_data['editdom', 'domtable', 'dragrows']  = dragrows
-    page_data['editdom', 'domtable', 'droprows']  = droprows
-    page_data['editdom', 'domtable', 'contents']  = domcontents
+
+    sd_editdom = SectionData("editdom")
+    sd_editdom['domtable', 'dragrows']  = dragrows
+    sd_editdom['domtable', 'droprows']  = droprows
+    sd_editdom['domtable', 'contents']  = domcontents
+    pd.update(sd_editdom)
+
 
 
 
@@ -961,7 +1017,7 @@ def move_down_in_page_dom(skicall):
     "Called by domtable to move an item in a page down"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
@@ -1039,9 +1095,12 @@ def move_down_in_page_dom(skicall):
 
     # and re-draw the table
     domcontents, dragrows, droprows = _page_domcontents(editedprojname, pagenumber, location_string)
-    page_data['editdom', 'domtable', 'dragrows']  = dragrows
-    page_data['editdom', 'domtable', 'droprows']  = droprows
-    page_data['editdom', 'domtable', 'contents']  = domcontents
+
+    sd_editdom = SectionData("editdom")
+    sd_editdom['domtable', 'dragrows']  = dragrows
+    sd_editdom['domtable', 'droprows']  = droprows
+    sd_editdom['domtable', 'contents']  = domcontents
+    pd.update(sd_editdom)
 
 
 
@@ -1049,7 +1108,7 @@ def move_down_right_in_page_dom(skicall):
     "Called by domtable to move an item in a page down and to the right"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
@@ -1127,9 +1186,12 @@ def move_down_right_in_page_dom(skicall):
 
     # and re-draw the table
     domcontents, dragrows, droprows = _page_domcontents(editedprojname, pagenumber, location_string)
-    page_data['editdom', 'domtable', 'dragrows']  = dragrows
-    page_data['editdom', 'domtable', 'droprows']  = droprows
-    page_data['editdom', 'domtable', 'contents']  = domcontents
+
+    sd_editdom = SectionData("editdom")
+    sd_editdom['domtable', 'dragrows']  = dragrows
+    sd_editdom['domtable', 'droprows']  = droprows
+    sd_editdom['domtable', 'contents']  = domcontents
+    pd.update(sd_editdom)
 
 
 
@@ -1137,8 +1199,7 @@ def after_dom_edit(skicall):
     "Called after a dom edit to refresh the correct page"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
-    print(call_data)
+
     if 'location_string' in call_data:
         if call_data['location_string'] == 'head':
             del call_data['location_string']
@@ -1165,7 +1226,7 @@ def move_in_page_dom(skicall):
     "Called by domtable to move an item in a page after a drag and drop"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
@@ -1273,16 +1334,19 @@ def move_in_page_dom(skicall):
 
     # and re-draw the table
     domcontents, dragrows, droprows = _page_domcontents(editedprojname, pagenumber, location_string)
-    page_data['editdom', 'domtable', 'dragrows']  = dragrows
-    page_data['editdom', 'domtable', 'droprows']  = droprows
-    page_data['editdom', 'domtable', 'contents']  = domcontents
+
+    sd_editdom = SectionData("editdom")
+    sd_editdom['domtable', 'dragrows']  = dragrows
+    sd_editdom['domtable', 'droprows']  = droprows
+    sd_editdom['domtable', 'contents']  = domcontents
+    pd.update(sd_editdom)
+
 
 
 def edit_page_dom(skicall):
     "Called by domtable to edit an item in a page"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
@@ -1359,7 +1423,7 @@ def cut_page_dom(skicall):
     "Called by domtable to remove an item in a page"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
@@ -1403,7 +1467,7 @@ def cut_page_dom(skicall):
         jsonstring = json.dumps(['Part',itemdict], indent=0, separators=(',', ':'))
     else:
         jsonstring = json.dumps([itempart,itemdict], indent=0, separators=(',', ':'))
-    page_data['localStorage'] = {'ski_part':jsonstring}
+    pd.localStorage = {'ski_part':jsonstring}
 
     # remove the item
     try:
@@ -1413,9 +1477,12 @@ def cut_page_dom(skicall):
 
     # and re-draw the table
     domcontents, dragrows, droprows = _page_domcontents(editedprojname, pagenumber, location_string)
-    page_data['editdom', 'domtable', 'dragrows']  = dragrows
-    page_data['editdom', 'domtable', 'droprows']  = droprows
-    page_data['editdom', 'domtable', 'contents']  = domcontents
+
+    sd_editdom = SectionData("editdom")
+    sd_editdom['domtable', 'dragrows']  = dragrows
+    sd_editdom['domtable', 'droprows']  = droprows
+    sd_editdom['domtable', 'contents']  = domcontents
+    pd.update(sd_editdom)
 
     # once item is deleted, no info on the item should be
     # left in call_data - this may not be required in future
@@ -1436,7 +1503,7 @@ def delete_page_dom(skicall):
     "Called by domtable to delete an item in a page"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
 
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
@@ -1481,9 +1548,12 @@ def delete_page_dom(skicall):
 
     # and re-draw the table
     domcontents, dragrows, droprows = _page_domcontents(editedprojname, pagenumber, location_string)
-    page_data['editdom', 'domtable', 'dragrows']  = dragrows
-    page_data['editdom', 'domtable', 'droprows']  = droprows
-    page_data['editdom', 'domtable', 'contents']  = domcontents
+
+    sd_editdom = SectionData("editdom")
+    sd_editdom['domtable', 'dragrows']  = dragrows
+    sd_editdom['domtable', 'droprows']  = droprows
+    sd_editdom['domtable', 'contents']  = domcontents
+    pd.update(sd_editdom)
 
     # once item is deleted, no info on the item should be
     # left in call_data - this may not be required in future
