@@ -4,12 +4,16 @@ from ... import FailPage, ValidateError, GoTo, ServerError, skilift
 
 from ....skilift import editpage, editsection
 
+from ....ski.project_class_definition import SectionData
+
 
 def insert_in_page(skicall):
     """Called by domtable to either insert or append an item in a page
        sets page_data to populate the insert or append modal panel"""
+
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
+
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
     else:
@@ -58,35 +62,42 @@ def insert_in_page(skicall):
         insert_location = location_string
 
     # display the modal panel
-    page_data[("pageinserts","insertitem","hide")] = False
+
+    sd = SectionData("pageinserts")
+
+    sd["insertitem","hide"] = False
 
     if (part_tuple.part_type == "Part") or (part_tuple.part_type == "Section"):
         # insert
-        page_data[("pageinserts","insertpara","para_text")] = "Choose an item to insert"
-        page_data[("pageinserts","insertupload","para_text")] = "Or insert a new block by uploading a block definition file:"
+        sd["insertpara","para_text"] = "Choose an item to insert"
+        sd["insertupload","para_text"] = "Or insert a new block by uploading a block definition file:"
     else:
         # append
-        page_data[("pageinserts","insertpara","para_text")] = "Choose an item to append"
-        page_data[("pageinserts","insertupload","para_text")] = "Or append a new block by uploading a block definition file:"
+        sd["insertpara","para_text"] = "Choose an item to append"
+        sd["insertupload","para_text"] = "Or append a new block by uploading a block definition file:"
 
     # for each of the links, set get_field1 to be the insert_location
-    page_data[("pageinserts","insert_text","get_field1")] = insert_location
-    page_data[("pageinserts","insert_textblock","get_field1")] = insert_location
-    page_data[("pageinserts","insert_symbol","get_field1")] = insert_location
-    page_data[("pageinserts","insert_comment","get_field1")] = insert_location
-    page_data[("pageinserts","insert_element","get_field1")] = insert_location
-    page_data[("pageinserts","insert_widget","get_field1")] = insert_location
-    page_data[("pageinserts","insert_section","get_field1")] = insert_location
+    sd["insert_text","get_field1"] = insert_location
+    sd["insert_textblock","get_field1"] = insert_location
+    sd["insert_symbol","get_field1"] = insert_location
+    sd["insert_comment","get_field1"] = insert_location
+    sd["insert_element","get_field1"] = insert_location
+    sd["insert_widget","get_field1"] = insert_location
+    sd["insert_section","get_field1"] = insert_location
 
     # set the hidden field
-    page_data[("pageinserts","uploadpart","hidden_field1")] = insert_location
+    sd["uploadpart","hidden_field1"] = insert_location
 
+    # update the PageData object with this SectionData object
+    pd.update(sd)
 
 
 def insert_text(skicall):
     "Inserts text into a page"
+
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
+
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
     else:
@@ -131,15 +142,20 @@ def insert_text(skicall):
     call_data['location'] = new_location
     
     # go to edit text page
-    page_data[("adminhead","page_head","large_text")] = "Edit Text in page : %s" % (pagenumber,)
+    sd_adminhead = SectionData("adminhead")
+    sd_adminhead["page_head","large_text"] = "Edit Text in page : %s" % (pagenumber,)
+    pd.update(sd_adminhead)
+
     # Set the text in the text area
-    page_data[("text_input","input_text")] = new_text
+    pd["text_input","input_text"] = new_text
 
 
 def insert_textblock(skicall):
     "Fills the template page for creating a textblock reference which will be inserted in the edited page"
+
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
+
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
     else:
@@ -182,22 +198,26 @@ def insert_textblock(skicall):
 
     # and set page data for the template page which inserts an textblock reference
 
-    page_data[("adminhead","page_head","large_text")] = "Insert TextBlock in page %s" % (pagenumber,)
+    sd_adminhead = SectionData("adminhead")
+    sd_adminhead["page_head","large_text"] = "Insert TextBlock in page %s" % (pagenumber,)
+    pd.update(sd_adminhead)
 
-    page_data[("linebreaks","radio_values")]=['ON', 'OFF']
-    page_data[("linebreaks","radio_text")]=['On', 'Off']
-    page_data[("linebreaks","radio_checked")] = 'ON'
+    pd["linebreaks","radio_values"]=['ON', 'OFF']
+    pd["linebreaks","radio_text"]=['On', 'Off']
+    pd["linebreaks","radio_checked"] = 'ON'
 
-    page_data[("setescape","radio_values")]=['ON', 'OFF']
-    page_data[("setescape","radio_text")]=['On', 'Off']
-    page_data[("setescape","radio_checked")] = 'ON'
+    pd["setescape","radio_values"]=['ON', 'OFF']
+    pd["setescape","radio_text"]=['On', 'Off']
+    pd["setescape","radio_checked"] = 'ON'
 
 
 
 def insert_symbol(skicall):
     "Inserts html symbol into a page"
+
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
+
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
     else:
@@ -241,14 +261,20 @@ def insert_symbol(skicall):
     
     # go to edit symbol page
     sym = editpage.get_symbol(editedprojname, pagenumber, call_data['pchange'], new_location)
-    page_data[("adminhead","page_head","large_text")] = "Edit Symbol in page : %s" % (pagenumber,)
-    page_data["symbol_input","input_text"] = sym
+
+    sd_adminhead = SectionData("adminhead")
+    sd_adminhead["page_head","large_text"] = "Edit Symbol in page : %s" % (pagenumber,)
+    pd.update(sd_adminhead)
+
+    pd["symbol_input","input_text"] = sym
 
 
 def insert_comment(skicall):
     "Inserts a comment into a page"
+
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
+
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
     else:
@@ -292,14 +318,20 @@ def insert_comment(skicall):
     
     # go to edit comment page
     com = editpage.get_comment(editedprojname, pagenumber, call_data['pchange'], new_location)
-    page_data[("adminhead","page_head","large_text")] = "Edit Comment in page : %s" % (pagenumber,)
-    page_data[("comment_input","input_text")] = com
+
+    sd_adminhead = SectionData("adminhead")
+    sd_adminhead["page_head","large_text"] = "Edit Comment in page : %s" % (pagenumber,)
+    pd.update(sd_adminhead)
+
+    pd["comment_input","input_text"] = com
 
 
 def insert_element(skicall):
     "Fills the template page for creating an html element which will be inserted in the edited page"
+
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
+
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
     else:
@@ -341,13 +373,17 @@ def insert_element(skicall):
     call_data['location'] = location
 
     # and set page data for the template page which inserts an element
-    page_data[("adminhead","page_head","large_text")] = "Insert an HTML element into page %s" % (pagenumber,)
+    sd_adminhead = SectionData("adminhead")
+    sd_adminhead["page_head","large_text"] = "Insert an HTML element into page %s" % (pagenumber,)
+    pd.update(sd_adminhead)
+
 
 
 def insert_widget(skicall):
     "Gets page number and location, used for creating a widget which will be inserted in the page"
+
     call_data = skicall.call_data
-    page_data = skicall.page_data
+
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
     else:
@@ -394,8 +430,10 @@ def insert_widget(skicall):
 
 def insert_section(skicall):
     "Gets page number and location, used for creating a section reference which will be inserted in the page"
+
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
+
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
     else:
@@ -437,25 +475,28 @@ def insert_section(skicall):
     call_data['location'] = location
 
     # Fill in header
-    page_data[("adminhead","page_head","large_text")] = "Insert Section place holder"
+    sd_adminhead = SectionData("adminhead")
+    sd_adminhead["page_head","large_text"] = "Insert Section place holder"
+    pd.update(sd_adminhead)
 
     # get current sections
     section_list = editsection.list_section_names(editedprojname)
     if not section_list:
-        page_data[("nosection", "show")] = True
-        page_data[("descript", "show")] = False
-        page_data[("placename","show")] = False
+        pd["nosection", "show"] = True
+        pd["descript", "show"] = False
+        pd["placename","show"] = False
         return
 
-    page_data[('sectionname','option_list')] = section_list[:]
-    page_data[('sectionname','selectvalue')] = section_list[0]
+    pd['sectionname','option_list'] = section_list[:]
+    pd['sectionname','selectvalue'] = section_list[0]
 
 
 
 def insert_upload(skicall):
     "Gets page number and location, used for creating a widget which will be inserted in the page"
+
     call_data = skicall.call_data
-    page_data = skicall.page_data
+
     if "page_number" in call_data:
         pagenumber = call_data["page_number"]
     else:
