@@ -6,6 +6,10 @@ from ... import ServerError, FailPage, ValidateError, GoTo
 from ... import skilift
 from ....skilift import editwidget, editvalidator
 
+from .. import utils
+
+from ....ski.project_class_definition import SectionData
+
 
 def _field_name(widget, field_argument):
     "Returns a field name"
@@ -21,7 +25,8 @@ def retrieve_editvalidator(skicall):
     "Fills in the edit a validator page"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
+    sd = SectionData("adminhead")
 
     project = call_data['editedprojname']
     section_name = None
@@ -43,11 +48,6 @@ def retrieve_editvalidator(skicall):
     else:
         raise FailPage("Field not identified")
 
-    if section_name:
-        page_data[("validator_displaywidget_textblock","replace_strings")] = ['If the widget is in this section, the name should be of the form %s,widget_name.' % (section_name,)]
-    else:
-        page_data[("validator_displaywidget_textblock","replace_strings")] = ['If the widget is in a section, the name should be of the form section_alias,widget_name.']
-
     # get validator
     try:
         validx = int(call_data['validx'])
@@ -71,20 +71,45 @@ def retrieve_editvalidator(skicall):
 
     call_data['extend_nav_buttons'].append(["back_to_field_edit", "Back to field", True, ''])
 
-    page_data[("adminhead","page_head","large_text")] = "Edit : %s on field %s" % (vinfo.validator, field_name)
+    sd["page_head","large_text"] = "Edit : %s on field %s" % (vinfo.validator, field_name)
+    pd.update(sd)
 
-    page_data[('widget_type','para_text')] = "Widget type : %s.%s" % (widgetdescription.modulename, widgetdescription.classname)
-    page_data[('widget_name','para_text')] = "Widget name : %s" % (widget_name,)
-    page_data[('field_type','para_text')] = "Field type : %s" % (field_arg,)
-    page_data[('field_name','para_text')] = "Field name : %s" % (field_name,)
-    page_data[('validator_type','para_text')] = "Validator type : %s.%s" % (vinfo.module_name,vinfo.validator)
+    pd['widget_type','para_text'] = "Widget type : %s.%s" % (widgetdescription.modulename, widgetdescription.classname)
+    pd['widget_name','para_text'] = "Widget name : %s" % (widget_name,)
+    pd['field_type','para_text'] = "Field type : %s" % (field_arg,)
+    pd['field_name','para_text'] = "Field name : %s" % (field_name,)
+    pd['validator_type','para_text'] = "Validator type : %s.%s" % (vinfo.module_name,vinfo.validator)
 
-    page_data[('validator_textblock','textblock_ref')] = ".".join(("validators",vinfo.module_name,vinfo.validator))
+    pd['validator_textblock','textblock_ref'] = ".".join(("validators",vinfo.module_name,vinfo.validator))
 
-    page_data[('e_message','input_text')] = vinfo.message
-    page_data[('e_message_ref','input_text')] = vinfo.message_ref
+    # error message
+    sd_error_message = utils.formtextinput( "error_message",                              # section alias
+                                            "validators.about_error_message",             # textblock
+                                            "The error message to be displayed:",         # field label
+                                            vinfo.message,                                # input text
+                                            action = "e_message",
+                                            left_label = "Submit the error message : ")
+    pd.update(sd_error_message)
 
-    page_data[('displaywidget','input_text')] = vinfo.displaywidget
+
+    # error reference message
+    sd_error_ref = utils.formtextinput( "error_ref",                                                   # section alias
+                                        "validators.about_error_ref",                                  # textblock
+                                        "A TextBlock reference string can provide the error message:", # field label
+                                        vinfo.message_ref,                                             # input text
+                                        action =  "e_message_ref",
+                                        left_label = "Submit the reference string : ")
+    pd.update(sd_error_ref)
+
+    
+    failsectionwidget = vinfo.displaywidget
+    if "," in failsectionwidget:
+        failsection,failwidget = failsectionwidget.split(",")
+        pd['failsection','input_text'] = failsection
+        pd['failwidget','input_text'] = failwidget
+    else:
+        pd['failsection','input_text'] = ""
+        pd['failwidget','input_text'] = failsectionwidget
 
     # list of allowed values
     contents = []
@@ -93,10 +118,20 @@ def retrieve_editvalidator(skicall):
         row = [val, str(idx)]
         contents.append(row)
     if contents:
-        page_data[('allowed_values','contents')] = contents
-        page_data[('allowed_values','show')] = True
+        pd['allowed_values','contents'] = contents
+        pd['allowed_values','show'] = True
     else:
-        page_data[('allowed_values','show')] = False
+        pd['allowed_values','show'] = False
+
+
+    # add an allowed value
+    sd_add_allowed_value = utils.formtextinput( "add_allowed_value",                     # section alias
+                                                "validators.add_allowed_value",          # textblock
+                                                "Add an allowed value to list:",         # field label
+                                                "",                                      # input text
+                                                action = "add_allowed_value",
+                                                left_label = "Submit a value : ")
+    pd.update(sd_add_allowed_value)
 
     # Validator arguments
     arg_contents = []
@@ -106,19 +141,18 @@ def retrieve_editvalidator(skicall):
         arg_contents.append(row)
     if arg_contents:
         arg_contents.sort(key=lambda x: x[0])
-        page_data[('validator_args','contents')] = arg_contents
-        page_data[('validator_args','show')] = True
-        page_data[('description5','show')] = True
+        pd['validator_args','contents'] = arg_contents
+        pd['validator_args','show'] = True
+        pd['description5','show'] = True
     else:
-        page_data[('validator_args','show')] = False
-        page_data[('description5','show')] = False
+        pd['validator_args','show'] = False
+        pd['description5','show'] = False
 
 
 def set_e_message(skicall):
     "Sets a validator error message"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     section_name = None
@@ -140,11 +174,12 @@ def set_e_message(skicall):
     else:
         raise FailPage("Field not identified")
 
-    if 'e_message' not in call_data:
+
+    if ('error_message','textinput','input_text') not in call_data:
         raise FailPage("Error message not given")
 
-    if call_data['e_message']:
-        e_message = call_data['e_message']
+    if call_data['error_message','textinput','input_text']:
+        e_message = call_data['error_message','textinput','input_text']
     else:
         e_message = ''
 
@@ -169,7 +204,6 @@ def set_e_message_ref(skicall):
     "Sets a validator error message reference"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     section_name = None
@@ -191,11 +225,11 @@ def set_e_message_ref(skicall):
     else:
         raise FailPage("Field not identified")
 
-    if 'e_message_ref' not in call_data:
+    if ('error_ref','textinput','input_text') not in call_data:
         raise FailPage("Error message reference not given")
 
-    if call_data['e_message_ref']:
-        e_message_ref = call_data['e_message_ref']
+    if call_data['error_ref','textinput','input_text']:
+        e_message_ref = call_data['error_ref','textinput','input_text']
     else:
         e_message_ref = ''
 
@@ -220,7 +254,6 @@ def set_displaywidget(skicall):
     "Sets a validator displaywidget"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     section_name = None
@@ -242,14 +275,17 @@ def set_displaywidget(skicall):
     else:
         raise FailPage("Field not identified")
 
-    if 'displaywidget' not in call_data:
+    if ('failwidget', 'input_text') not in call_data:
         raise FailPage("Display widget not given")
 
-    if call_data['displaywidget']:
-        displaywidget = call_data['displaywidget']
+    if call_data['failwidget', 'input_text']:
+        displaywidget = call_data['failwidget', 'input_text']
     else:
         displaywidget = ''
 
+    if (('failsection', 'input_text') in call_data) and call_data['failsection', 'input_text'] and displaywidget:
+        displaywidget = call_data['failsection', 'input_text'] + "," + displaywidget
+
     # get validator index
     try:
         validx = int(call_data['validx'])
@@ -271,7 +307,6 @@ def set_allowed_value(skicall):
     "Adds a validator allowed value"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     section_name = None
@@ -299,11 +334,11 @@ def set_allowed_value(skicall):
     except Exception:
         raise FailPage("Invalid validator")
 
-    if 'add_allowed' not in call_data:
+    if ('add_allowed_value','textinput','input_text') not in call_data:
         raise FailPage("Allowed value to be added not given")
 
-    if call_data['add_allowed']:
-        allowed_value = call_data['add_allowed']
+    if call_data['add_allowed_value','textinput','input_text']:
+        allowed_value = call_data['add_allowed_value','textinput','input_text']
     else:
         raise FailPage("A none-empty string is required")
 
@@ -322,7 +357,6 @@ def remove_allowed_value(skicall):
     "Removes a validator allowed value"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     section_name = None
@@ -373,7 +407,8 @@ def retrieve_arg(skicall):
     "Fills in the edit a validator argument page"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
+    sd = SectionData("adminhead")
 
     project = call_data['editedprojname']
     section_name = None
@@ -411,12 +446,11 @@ def retrieve_arg(skicall):
             widgetdescription = editwidget.section_widget_description(project, section_name, call_data['schange'], widget_name)
             widget =  editwidget.section_widget(project, section_name, call_data['schange'], widget_name)
             vinfo = editvalidator.section_field_validator_info(project, section_name, call_data['schange'], widget_name, field_arg, validx)
-            page_data[("validator_displaywidget_textblock","replace_strings")] = ['If the widget is in this section, the name should be of the form %s,widget_name.' % (section_name,)]
         else:
             widgetdescription = editwidget.page_widget_description(project, pagenumber, call_data['pchange'], widget_name)
             widget = editwidget.page_widget(project, pagenumber, call_data['pchange'], widget_name)
             vinfo = editvalidator.page_field_validator_info(project, pagenumber, call_data['pchange'], widget_name, field_arg, validx)
-            page_data[("validator_displaywidget_textblock","replace_strings")] = ['If the widget is in a section, the name should be of the form section_alias,widget_name.']
+
     except ServerError as e:
         raise FailPage(e.message)
 
@@ -428,25 +462,32 @@ def retrieve_arg(skicall):
     call_data['extend_nav_buttons'].extend([["back_to_field_edit", "Back to field", True, ''],["back_to_validator", "Back to validator", True, '']])
 
     # navigator text
-    page_data[("adminhead","page_head","large_text")] = arg_name
+    sd["page_head","large_text"] = arg_name
+    pd.update(sd)
 
-    page_data[('widget_type','para_text')] = "Widget type : %s.%s" % (widgetdescription.modulename, widgetdescription.classname)
-    page_data[('widget_name','para_text')] = "Widget name : %s" % (widget_name,)
-    page_data[('field_type','para_text')] = "Field type : %s" % (field_arg,)
-    page_data[('field_name','para_text')] = "Field name : %s" % (field_name,)
-    page_data[('validator_type','para_text')] = "Validator type : %s.%s" % (vinfo.module_name,vinfo.validator)
+    pd['widget_type','para_text'] = "Widget type : %s.%s" % (widgetdescription.modulename, widgetdescription.classname)
+    pd['widget_name','para_text'] = "Widget name : %s" % (widget_name,)
+    pd['field_type','para_text'] = "Field type : %s" % (field_arg,)
+    pd['field_name','para_text'] = "Field name : %s" % (field_name,)
+    pd['validator_type','para_text'] = "Validator type : %s.%s" % (vinfo.module_name,vinfo.validator)
 
-    page_data[('validator_arg_textblock','textblock_ref')] = ".".join(("validators",vinfo.module_name,vinfo.validator,arg_name))
+    # validator argument form
+    tblockref = ".".join(("validators",vinfo.module_name,vinfo.validator,arg_name))
+    sd_validator_argument = utils.formtextinput("validator_argument",                         # section alias
+                                                tblockref,                                    # textblock
+                                                "Set the validator parameter:",               # field label
+                                                vinfo.val_args[arg_name],                     # input text
+                                                action = "validator_parameter",
+                                                hidden_field1 = arg_name,
+                                                left_label = "Submit the value : ")
+    pd.update(sd_validator_argument)
 
-    page_data[('arg_val','input_text')] = vinfo.val_args[arg_name]
-    page_data[('arg_val','hidden_field1')] = arg_name
 
 
 def set_arg_value(skicall):
     "Sets a validator argument value"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     section_name = None
@@ -496,7 +537,6 @@ def move_up(skicall):
     "Moves a validator up in a field validator list"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     section_name = None
@@ -542,7 +582,6 @@ def move_down(skicall):
     "Moves a validator down in a field validator list"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     section_name = None
@@ -585,7 +624,6 @@ def remove_validator(skicall):
     "Removes a validator"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     section_name = None
@@ -630,7 +668,8 @@ def retrieve_validator_modules(skicall):
     "Creates a list of validator modules"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
+    sd = SectionData("adminhead")
 
     project = call_data['editedprojname']
     section_name = None
@@ -666,12 +705,13 @@ def retrieve_validator_modules(skicall):
 
     field_name = _field_name(widget, field_arg)
 
-    page_data[("adminhead","page_head","large_text")] = "Add validator to (\"%s\",\"%s\")" % (widget_name, field_name)
+    sd["page_head","large_text"] = "Add validator to (\"%s\",\"%s\")" % (widget_name, field_name)
+    pd.update(sd)
 
-    page_data[('widget_type','para_text')] = "Widget type : %s.%s" % (widgetdescription.modulename, widgetdescription.classname)
-    page_data[('widget_name','para_text')] = "Widget name : %s" % (widget_name,)
-    page_data[('field_type','para_text')] = "Field type : %s" % (field_arg,)
-    page_data[('field_name','para_text')] = "Field name : %s" % (field_name,)
+    pd['widget_type','para_text'] = "Widget type : %s.%s" % (widgetdescription.modulename, widgetdescription.classname)
+    pd['widget_name','para_text'] = "Widget name : %s" % (widget_name,)
+    pd['field_type','para_text'] = "Field type : %s" % (field_arg,)
+    pd['field_name','para_text'] = "Field name : %s" % (field_name,)
 
     call_data['extend_nav_buttons'].append(["back_to_field_edit", "Back to field", True, ''])
 
@@ -686,14 +726,15 @@ def retrieve_validator_modules(skicall):
 
     validator_modules = editvalidator.validator_modules()
 
-    page_data[("modulestable","link_table")] = [ [name, name, '', ".".join(('validators', name, 'module')), 'Description not found', ''] for name in validator_modules ]
+    pd["modulestable","link_table"] = [ [name, name, '', ".".join(('validators', name, 'module')), 'Description not found', ''] for name in validator_modules ]
 
 
 def retrieve_validator_list(skicall):
     "Creates a list of validators"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
+    pd = call_data['pagedata']
+    sd = SectionData("adminhead")
 
     project = call_data['editedprojname']
     section_name = None
@@ -729,12 +770,13 @@ def retrieve_validator_list(skicall):
 
     field_name = _field_name(widget, field_arg)
 
-    page_data[("adminhead","page_head","large_text")] = "Add validator to (\"%s\",\"%s\")" % (widget_name, field_name)
+    sd["page_head","large_text"] = "Add validator to (\"%s\",\"%s\")" % (widget_name, field_name)
+    pd.update(sd)
 
-    page_data[('widget_type','para_text')] = "Widget type : %s.%s" % (widgetdescription.modulename, widgetdescription.classname)
-    page_data[('widget_name','para_text')] = "Widget name : %s" % (widget_name,)
-    page_data[('field_type','para_text')] = "Field type : %s" % (field_arg,)
-    page_data[('field_name','para_text')] = "Field name : %s" % (field_name,)
+    pd['widget_type','para_text'] = "Widget type : %s.%s" % (widgetdescription.modulename, widgetdescription.classname)
+    pd['widget_name','para_text'] = "Widget name : %s" % (widget_name,)
+    pd['field_type','para_text'] = "Field type : %s" % (field_arg,)
+    pd['field_name','para_text'] = "Field name : %s" % (field_name,)
 
     call_data['extend_nav_buttons'].extend([["back_to_field_edit", "Back to field", True, ''],["validator_modules", "Modules", True, '']])
 
@@ -748,7 +790,7 @@ def retrieve_validator_list(skicall):
     if module_name not in validator_modules:
         raise FailPage("Module not identified")
 
-    page_data[('moduledesc','textblock_ref')] = 'validators.' + module_name + '.module'
+    pd['moduledesc','textblock_ref'] = 'validators.' + module_name + '.module'
 
     # table of validators
 
@@ -761,14 +803,13 @@ def retrieve_validator_list(skicall):
 
     # tuple of validators in the module
     validators = editvalidator.validators_in_module(module_name)
-    page_data[("validators","link_table")] = [ [name, name, module_name, ".".join(("validators",module_name,name)), 'Description not found', ''] for name in validators ]
+    pd["validators","link_table"] = [ [name, name, module_name, ".".join(("validators",module_name,name)), 'Description not found', ''] for name in validators ]
 
 
 def create_validator(skicall):
     "Creates a validator and adds it to the field"
 
     call_data = skicall.call_data
-    page_data = skicall.page_data
 
     project = call_data['editedprojname']
     section_name = None
